Package: nhanesdata
Title: Harmonized Access to NHANES Survey Data
Version: 0.2.2
Authors@R: c(
    person(
        "Kyle", "Grealis",
        email = "kyle@kylegrealis.com",
        role = c("aut", "cre"),
        comment = c(ORCID = "0000-0002-9223-8854")
    ),
    person(
        "Amrit", "Baral",
        email = "abaral3@jhu.edu",
        role = "ctb",
        comment = c(ORCID = "0000-0002-0961-9665")
    ),
    person(
        "Natalie", "Neugaard",
        email = "nataliegoulett@gmail.com",
        role = "ctb",
        comment = c(ORCID = "0009-0008-0820-5111")
    ),
    person(
        "Raymond", "Balise",
        email = "balise@miami.edu",
        role = "ctb",
        comment = c(ORCID = "0000-0002-9856-5901")
    ),
    person(
        "Johannes", "Thrul",
        email = "jthrul@jhu.edu",
        role = "ctb",
        comment = c(ORCID = "0000-0001-8929-9579")
    ),
    person(
        "Janardan", "Devkota",
        email = "jdevkot1@jhu.edu",
        role = "ctb",
        comment = c(ORCID = "0009-0007-6734-777X")
    )
    )
Description: Instant access to harmonized National Health and Nutrition Examination Survey (NHANES) data spanning 1999-2023. Retrieve pre-processed datasets from reliable cloud storage with automatic type reconciliation and integrated search tools for variables and datasets. Simplifies NHANES data workflows by handling cycle management and maintaining data consistency across survey waves. Data is sourced from <https://www.cdc.gov/nchs/nhanes/>.
License: MIT + file LICENSE
URL: https://github.com/kyleGrealis/nhanesdata,
        https://www.kylegrealis.com/nhanesdata/
BugReports: https://github.com/kyleGrealis/nhanesdata/issues
Language: en-US
Encoding: UTF-8
RoxygenNote: 7.3.3
Depends: R (>= 4.1.0)
Imports: arrow, dplyr, nhanesA, rlang, scales, stringr, srvyr, tibble
Suggests: cli, curl, devtools, fs, ggplot2, httptest2, janitor,
        jsonlite, knitr, paws.storage, purrr, reactable, rmarkdown,
        roxygen2, testthat (>= 3.0.0), tools, withr, yaml
Config/testthat/edition: 3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-05-04 18:37:30 UTC; kxg679
Author: Kyle Grealis [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-9223-8854>),
  Amrit Baral [ctb] (ORCID: <https://orcid.org/0000-0002-0961-9665>),
  Natalie Neugaard [ctb] (ORCID: <https://orcid.org/0009-0008-0820-5111>),
  Raymond Balise [ctb] (ORCID: <https://orcid.org/0000-0002-9856-5901>),
  Johannes Thrul [ctb] (ORCID: <https://orcid.org/0000-0001-8929-9579>),
  Janardan Devkota [ctb] (ORCID: <https://orcid.org/0009-0007-6734-777X>)
Maintainer: Kyle Grealis <kyle@kylegrealis.com>
Repository: CRAN
Date/Publication: 2026-05-04 19:30:06 UTC
Built: R 4.6.0; ; 2026-05-05 00:22:34 UTC; unix
