# Generated by roxygen2: do not edit by hand

export(create_design)
export(get_url)
export(read_nhanes)
export(term_search)
export(var_search)
import(dplyr)
importFrom(arrow,read_parquet)
importFrom(nhanesA,nhanes)
importFrom(nhanesA,nhanesSearch)
importFrom(nhanesA,nhanesSearchVarName)
importFrom(rlang,abort)
importFrom(scales,comma)
importFrom(srvyr,as_survey_design)
importFrom(stringr,str_to_upper)
importFrom(tibble,tibble)
importFrom(utils,globalVariables)
